@@ -9,6 +9,7 @@ import (
 	"path"
 	"path/filepath"
 	"reflect"
+	"slices"
 	"sort"
 	"strings"
 
@@ -509,12 +510,28 @@ func FindCCConfigFile(gitRepoRoot string) (string, []string, error) {
 			}
 		}
 	}
-	configHome := os.Getenv("XDG_CONFIG_HOME")
-	if configHome == "" {
-		configHome = os.Getenv("HOME")
+	{ // handle $XDG_CONFIG_HOME
+		// > `$XDG_CONFIG_HOME`` defines the base directory relative to which user-specific
+		// > configuration files should be stored. If `$XDG_CONFIG_HOME` is either not set or
+		// > empty, a default equal to `$HOME/.config` should be used.
+		// >
+		// > -- https://specifications.freedesktop.org/basedir-spec/latest/#variables
+		xdgConfigHome := os.Getenv("XDG_CONFIG_HOME")
+		if xdgConfigHome == "" {
+			if home := os.Getenv("HOME"); home != "" {
+				xdgConfigHome = path.Join(home, ".config")
+			}
+		}
+		dirsToSearch = append(dirsToSearch, xdgConfigHome)
 	}
-	if configHome != "" {
-		dirsToSearch = append(dirsToSearch, configHome)
+	{ // handle $XDG_CONFIG_DIRS
+		// > `$XDG_CONFIG_DIRS` defines the preference-ordered set of base directories to
+		// > search for configuration files in addition to the `$XDG_CONFIG_HOME` base
+		// > directory. The directories in `$XDG_CONFIG_DIRS` should be separated with a
+		// > colon ':'.
+		// >
+		// > -- https://specifications.freedesktop.org/basedir-spec/latest/#variables
+		dirsToSearch = append(dirsToSearch, strings.Split(os.Getenv("XDG_CONFIG_DIRS"), ":")...)
 	}
 	tried := make([]string, 0, len(candidateFiles)*len(dirsToSearch))
 	for _, dir := range dirsToSearch {
@@ -551,19 +568,57 @@ func GetGitRepoRoot() (string, error) {
 	}
 }
 
-// find the git directory (usually ./.git)
-func getGitDir() (string, error) {
-	if env := os.Getenv("GIT_COMMON_DIR"); env != "" {
-		return env, nil
+// find the git directory (usually ./.git/)
+func getGitDir() (gitDir string, err error) {
+	var checked []string
+	// see https://git-scm.com/docs/git#Documentation/git.txt-codeGITCOMMONDIRcode
+	if gitDir = os.Getenv("GIT_COMMON_DIR"); gitDir != "" {
+		goto checkDirectory
 	}
-	if env := os.Getenv("GIT_DIR"); env != "" {
-		return env, nil
+	// see https://git-scm.com/book/en/v2/Git-Internals-Environment-Variables#:~:text=the%20current%20repository.-,git_dir,-is%20the%20location
+	// see https://git-scm.com/docs/git#Documentation/git.txt-codeGITDIRcode
+	if gitDir = os.Getenv("GIT_DIR"); gitDir != "" {
+		goto checkDirectory
 	}
-	out, err := stdoutFrom("git", "rev-parse", "--absolute-git-dir")
+	// see https://git-scm.com/book/en/v2/Git-Internals-Environment-Variables#_repository_locations:~:text=your%20shell%20prompt.-,git_work_tree,-is%20the%20location
+	// see https://git-scm.com/docs/git#Documentation/git.txt-codeGITWORKTREEcode
+	if gitDir = os.Getenv("GIT_WORK_TREE"); gitDir != "" {
+		goto checkDirectory
+	}
+	gitDir, err = stdoutFrom("git", "rev-parse", "--absolute-git-dir")
 	if err != nil {
 		return "", err
 	}
-	return out, nil
+	gitDir = strings.TrimSpace(gitDir)
+checkDirectory:
+	{ // follow .git files until we find a directory
+		checked = append(checked, gitDir)
+		if slices.Contains(checked[:len(checked)-1], gitDir) {
+			return "", fmt.Errorf(
+				"circular link in git directory lookup:\n  %s",
+				strings.Join(checked, "\n  "),
+			)
+		}
+
+		var info os.FileInfo
+		if info, err = os.Stat(gitDir); err != nil {
+			return "", err
+		}
+		if info.IsDir() {
+			return // ok! Found a plausible directory
+		}
+		var data []byte
+		data, err = os.ReadFile(gitDir)
+		if err != nil {
+			return
+		}
+		str := strings.TrimRight(string(data), " \t\r\n")
+		if !strings.HasPrefix(str, "gitdir:") {
+			return "", fmt.Errorf("unexpected content in %s: %s", gitDir, str)
+		}
+		gitDir = strings.TrimLeft(strings.TrimPrefix(str, "gitdir:"), " \t\r\n")
+		goto checkDirectory
+	}
 }
 
 func stdoutFrom(args ...string) (string, error) {
